using Microsoft.AspNetCore.Builder;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;

namespace Mirea.Api.Endpoint;

public class Program
{
    private static IConfigurationRoot ConfigureEnvironment()
    {
        EnvironmentManager.LoadEnvironment(".env");
        var environmentVariables = Environment.GetEnvironmentVariables()
            .OfType<DictionaryEntry>()
            .ToDictionary(
                entry => entry.Key.ToString() ?? string.Empty,
                entry => entry.Value?.ToString() ?? string.Empty
            );

        var result = new ConfigurationBuilder().AddInMemoryCollection(environmentVariables!);

        return result.Build();
    }

    public static void Main(string[] args)
    {
        var builder = WebApplication.CreateBuilder(args);
        builder.Configuration.AddConfiguration(ConfigureEnvironment());
        builder.Configuration.AddJsonFile(Settings.FilePath, optional: true, reloadOnChange: true);

        // Add services to the container.

        builder.Services.AddControllers();
        // Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle
        builder.Services.AddEndpointsApiExplorer();
        builder.Services.AddSwaggerGen();

        var app = builder.Build();

        // Configure the HTTP request pipeline.
        if (app.Environment.IsDevelopment())
        {
            app.UseSwagger();
            app.UseSwaggerUI();
        }

        app.UseHttpsRedirection();

        app.UseAuthorization();


        app.MapControllers();

        app.Run();
    }
}